
(*****************************************************************************)
(*                 Vhern hrac automat "The One Arm Bandit"                *)
(*                 (c) Ing. Miroslav Nmeek 1997, GEMA Soft                 *)
(*****************************************************************************)


(*============================ definice promnnch ==========================*)

# Znak                                     (* schova znaku z klvesnice     *)
# Skore                                    (* dosaen skre                 *)
# Vyhra                                    (* vhra v jedn he              *)
# Zvuk                                     (* 1=zapnut zvuk, -1=vypnut       *)

(*============================ definice pkaz =============================*)

(*-------------------------- vymazn celho pole ---------------------------*)
! Vymaz
  (
    x=0 y=1 sever                          (* nastaven vchoz pozice       *)
    NIC                                    (* vymazn prvnho polka       *)
    krok vpravo                            (* na 1. polko a otoen vpravo *)
    dokud neni ZED
      (
        dokud neni ZED (NIC krok)          (* vymazn dku zleva doprava   *)
        vpravo jestli neni ZED (krok vpravo) (* na zatek dalho dku     *)
        dokud neni zed (NIC krok)          (* vymazn dku zprava doleva   *)
        vlevo jestli neni ZED (krok vlevo) (* na zatek dalho dku       *)
      )
  )
(*------------------------------- vymazn sla ----------------------------*)
! Vymaz_Cislo
  (
    vychod                                 (* mae se zleva doprava          *)
    opakuj 5 (DIG krok)                    (* vymae slo                   *)
    krok vzad                              (* oto se na posledn pozici    *)
  )
(*------------------------------- zobrazen sla ---------------------------*)
! Zobraz_Cislo
  (
    Vymaz_Cislo                            (* vymazn sla                 *)
    opakuj 5                               (* opakuje se pro max. 5 slic   *)
      (
        predmet ^($ mod 10)                (* vykreslen nejni slice    *)
        $=$/10                             (* zmenen sla o d           *)
        jestli $=0 prerus                  (* potlaen nevznamnch nul     *)
        krok                               (* posun k dal slici          *)
      )
  )
(*------------------------------- zobrazen skre ---------------------------*)
! Zobraz_Skore
  (
    $=Skore                                (* zobrazen slo - skre        *)
    x=2 y=10                               (* pozice ped slem             *)
    Zobraz_Cislo                           (* zobrazen sla                *)
  )
(*----------------------------- vymazn sla vhry ------------------------*)
! Vymaz_Vyhru
  (
    x=2 y=8                                (* pozice ped slem             *)
    Vymaz_Cislo                            (* vymazn sla                 *)
  )
(*------------------------------- zobrazen vhry ---------------------------*)
! Zobraz_Vyhru
  (
    $=Vyhra                                (* zobrazen slo - vhra        *)
    x=2 y=8                                (* pozice ped slem             *)
    Zobraz_Cislo                           (* zobrazen sla                *)
  )
(*------------------------------ ohlen vhry -----------------------------*)
! Hlas_Vyhru
  (
    jestli Zvuk > 0
      jestli Vyhra < 10 hudba "++1cg" jinak
        jestli Vyhra < 50 hudba "++1cgcgcg" jinak
          jestli Vyhra < 100 hudba "++1cgcgcgcgcg" jinak
            hudba "++1cgcgcgcgcgcgcgcg"

    opakuj 10                              (* poet zablikn sla          *)
      (
        Vymaz_Vyhru                        (* vymazn sla vhry           *)
        cekej                              (* mal prodleva                  *)
        Zobraz_Vyhru                       (* zobrazen dosaen vhry       *)
        cekej cekej                        (* mal prodleva                  *)
        Znak=klavesa                       (* naten znaku z klvesnice     *)
        jestli Znak = k_F10 nebo Znak = k_Esc prerus  (* peruen programu  *)
     )
  )
(*------------------------------- zjitn vhry ----------------------------*)
! Zkus_Vyhru
  (
    Vyhra=0                                (* inicializace - nen vhra      *)
    x=3 y=4                                (* pozice prvnho oknka          *)

                                           (* test mince - 2 nebo 3 pozice   *)
    jestli pole x y = LOS1 a pole x+2 y = LOS1
      ( jestli pole x+4 y = LOS1 Vyhra = 20 jinak Vyhra = 2 )

                                           (* test ten - 2 nebo 3 pozice  *)
    jestli pole x y = LOS2 a pole x+2 y = LOS2
      ( jestli pole x+4 y = LOS2 Vyhra = 20 jinak Vyhra = 2 )

                                           (* test zvonku - 2 nebo 3 pozice  *)
    jestli pole x y = LOS3 a pole x+2 y = LOS3
      ( jestli pole x+4 y = LOS3 Vyhra = 50 jinak Vyhra = 5 )

                                           (* test Petra - 2 nebo 3 pozice   *)
    jestli pole x y = LOS4 a pole x+2 y = LOS4
      ( jestli pole x+4 y = LOS4 Vyhra = 100 jinak Vyhra = 10 )

                                           (* test Petry - 2 nebo 3 pozice   *)
    jestli pole x y = LOS5 a pole x+2 y = LOS5
      ( jestli pole x+4 y = LOS5 Vyhra = 100 jinak Vyhra = 10 )
  )
(*---------------------- zobrazen hlen (mal npovdy) ------------------*)
! Zobraz_Hlaseni
  (
    jestli Zvuk > 0
      hlaseni "%*mezera%*=losovn    %*F2%*=vypnut zvuku    %*F10%*=konec hry"
    jinak
      hlaseni "%*mezera%*=losovn    %*F2%*=zapnut zvuku    %*F10%*=konec hry"
  )
(*------------------------ losovn jednoho polka -------------------------*)
! Losuj_Jedno
  (
    jestli Nahoda 3 = 0 $=LOS1 jinak       (* s 33% pravdpodobnost mince   *)
      jestli Nahoda 2 = 0 $=LOS2 jinak     (* s 33% pravdpodobnost tee  *)
        jestli Nahoda 2 = 0 $=LOS3 jinak   (* s 16% pravdpodobnost zvonek  *)
          jestli Nahoda 2 = 0 $=LOS4 jinak (* s  8% pravdpodobnost Petr    *)
            $=LOS5                         (* s  8% pravdpodobnost Petra   *)
  )
(*---------------------------- losovn -------------------------------------*)
! Losuj
(
  Vymaz_Vyhru                            (* vymazn sla vhry           *)
  jestli Skore > 0 Skore=Skore-1         (* snen skre o 1 jako vklad   *)
  Zobraz_Skore                           (* zobrazen snenho skre      *)
  $=60                                   (* ta pro potn cykl       *)
  dokud neni ($=0 nebo Znak = k_F10 nebo Znak = k_Esc)
  (
    jestli $>40 pole 3 4 = Losuj_Jedno (* losovn prvnho pole          *)
    jestli $>20 pole 5 4 = Losuj_Jedno (* losovn druhho pole          *)
    pole 7 4 = Losuj_Jedno             (* losovn tetho pole          *)
    cekej                              (* mal prodleva pro zobrazen    *)
    $=$-1                              (* snen tae cykl           *)
    Znak=klavesa                       (* naten znaku z klvesnice     *)
    jestli Znak=k_F2 (Zvuk = -Zvuk Zobraz_Hlaseni) (* zmna zapnut zvuku*)
    jestli Zvuk > 0 a ($=40 nebo $=20 nebo $=0) hudba "++1g"  (* zvuk    *)
  )
  Zkus_Vyhru                             (* naten dosaen vhry         *)
  jestli Vyhra<>0                        (* je njak vhra ?              *)
  (
    Hlas_Vyhru                         (* ohlen vhry                 *)
        Skore=Skore+Vyhra                  (* piten vhry ke skre        *)
        Zobraz_Skore                       (* zobrazen novho skre         *)
      )
    klavesa                                (* vyprzdnn bufferu klvesnice *)
  )
(*----------------------- zobrazen skn automatu -------------------------*)
! Zobraz_Ram
  (
    pole x y   = AUT1, AUT2, AUT2, AUT2, AUT2, AUT2, AUT2, AUT2, AUT3
    pole x y+1 = AUT4                             pole x+8 y+1 = AUT6
    pole x y+2 = AUT4                             pole x+8 y+2 = AUT6
    pole x y+3 = AUT4                             pole x+8 y+3 = AUT6
    pole x y+4 = AUT4, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT6
    pole x y+5 = AUT4, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT6
    pole x y+6 = AUT4, AUT5                 pole x+7 y+6 = AUT5, AUT6
    pole x y+7 = AUT4, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT5, AUT6
    pole x y+8 = AUT4, AUT5                 pole x+7 y+8 = AUT5, AUT6
    pole x y+9 = AUT7, AUT8, AUT8, AUT8, AUT8, AUT8, AUT8, AUT8, AUT9
  )
(*----------------------- zobrazen panelu automatu -------------------------*)
! Zobraz_Panel
  (
    pole x y   = BOX1, BOX2, BOX3, BOX2, BOX3, BOX2, BOX4
    pole x y+1 = BOX5, LOS4, BOX7, LOS2, BOX7, LOS5, BOX8
    pole x y+2 = BOX9, BOXA, BOXB, BOXA, BOXB, BOXA, BOXC
  )
(*--------------------------- zobrazen npovdy ----------------------------*)
! Pomoc
  (
    pole x y   = LOS1, LOS1, CIS , CIS , CIS , CIS2  (* 2 mince .......... 2 *)
    pole x y+1 = LOS2, LOS2, CIS , CIS , CIS , CIS2  (* 2 ten ......... 2 *)
    pole x y+2 = LOS3, LOS3, CIS , CIS , CIS , CIS5  (* 2 zvonky ......... 5 *)
    pole x y+3 = LOS4, LOS4, CIS , CIS , CIS1, CIS0  (* 2 Peti ......... 10 *)
    pole x y+4 = LOS5, LOS5, CIS , CIS , CIS1, CIS0  (* 2 Petry ......... 10 *)
    pole x y+5 = LOS1, LOS1, LOS1, CIS , CIS2, CIS0  (* 3 mince ......... 20 *)
    pole x y+6 = LOS2, LOS2, LOS2, CIS , CIS2, CIS0  (* 3 ten ........ 20 *)
    pole x y+7 = LOS3, LOS3, LOS3, CIS , CIS5, CIS0  (* 3 zvonky ........ 50 *)
    pole x y+8 = LOS4, LOS4, LOS4, CIS1, CIS0, CIS0  (* 3 Peti ........ 100 *)
    pole x y+9 = LOS5, LOS5, LOS5, CIS1, CIS0, CIS0  (* 3 Petry ........ 100 *)
  )
(*------------------------- inicializace nov hry ---------------------------*)
! Nova
  (
    Skore=100                              (* inicializace skre             *)
    Vymaz                                  (* vymazn cel plochy           *)
    x=1  y=2 Zobraz_Ram                    (* vykreslen skn automatu     *)
    x=2  y=3 Zobraz_Panel                  (* vykreslen panelu automatu     *)
    Zobraz_Skore                           (* inicializan zobrazen skre  *)
    Vymaz_Vyhru                            (* vymazn sla vhry           *)
    x=11 y=2 Pomoc                         (* zobrazen npovdy             *)
    x=3 y=7 vychod text ""                 (* nadpis displeje vhry          *)
                   text "    %$9Vhra"
    x=3 y=9 vychod text ""                 (* nadpis displeje hotovosti      *)
                   text "   %$9Hotovost"
    Zobraz_Hlaseni                         (* zobrazen mal npovdy        *)
  )
(*============================= hlavn program ==============================*)

rychle                                     (* cel program v rychlm reimu  *)
^0=Dig0,Dig1,Dig2,Dig3,Dig4,Dig5,Dig6,Dig7,Dig8,Dig9 (* inic. tabulky slic *)
Znak=""                                    (* inicializace schovy znaku     *)
Zvuk=1                                     (* pznak zapnut zvuku          *)
Nova                                       (* inicializace nov hry          *)

Dokud neni (Znak=k_Esc nebo Znak=k_F10)    (* cyklus jedn hry               *)
  (
    Znak=klavesa                           (* naten znaku z klvesnice     *)
    jestli Znak=k_F2 (Zvuk = -Zvuk Zobraz_Hlaseni) (* zmna zapnut zvuku    *)
    jestli Znak=k_mezera nebo Znak=k_Enter Losuj (* losovn jedn hry       *)
  )
prerus
